/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JwsWebMethod.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.struct;

import org.ow2.util.ee.metadata.common.api.struct.IJavaxJwsWebMethod;


/**
 * Acts as an implementation of &#64;{@link javax.jws.WebMethod} annotation.
 * @author Florent Benoit
 */
public class JwsWebMethod implements IJavaxJwsWebMethod {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6693679073386907747L;

    /**
     * The action for this operation.
     */
    private String action = null;

    /**
     * excluded ?
     */
    private boolean excluded = false;

    /**
     * The name of the wsdl:operation matching this method.
     */
    private String operationName = null;


    /**
     * Constructor.<br>
     * Build object with default values.
     */
    public JwsWebMethod() {
        this.action = "";
        this.excluded = false;
        this.operationName = "";
    }

    /**
     * @return The action for this operation.
     */
    public String getAction() {
        return action;
    }

    /**
     * Sets the action for this operation.
     * @param action the given action
     */
    public void setAction(final String action) {
        this.action = action;
    }


    /**
     * Sets the exclude flag.
     * @param isExclude true/false
     */
    public void setExclude(final boolean isExclude) {
        this.excluded = isExclude;
    }

    /**
     * @return true if the method is excluded.
     */
    public boolean getExclude() {
        return excluded;
    }

    /**
     * Sets the name of the wsdl:operation matching this method.
     * @param operationName the given operation name
     */
    public void setOperationName(final String operationName) {
        this.operationName = operationName;
    }

    /**
     * @return the name of the wsdl:operation matching this method.
     */
    public String getOperationName() {
        return operationName;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // action
        sb.append("[action=");
        sb.append(action);

        // excluded
        sb.append(", excluded=");
        sb.append(excluded);

        // operationName
        sb.append(", operationName=");
        sb.append(operationName);

        sb.append("]");
        return sb.toString();
    }
}
